@@ -19,6 +19,9 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 
 #include "kwinglplatform.h"
+// include kwinglutils_funcs.h to avoid the redeclaration issues
+// between qopengl.h and epoxy/gl.h
+#include "kwinglutils_funcs.h"
 #include <epoxy/gl.h>
 
 #include <QRegExp>
